#
# spec file for package ghc-irc-ctcp
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name irc-ctcp
Name:           ghc-%{pkg_name}
Version:        0.1.3.0
Release:        1.11
Summary:        A CTCP encoding and decoding library for IRC clients
License:        MIT
Group:          System/Libraries
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
# Begin cabal-rpm deps:
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# End cabal-rpm deps

%description
CTCP (Client To Client Protocol) is a way of sending arbitrary data over an IRC
network, which may include bytes not allowed in standard IRC messages.
CTCPs are sent as a PRIVMSG or NOTICE, where the first and last characters as
'\001' (SOH), and special bytes are escaped by encoding them into a two-byte
sequence beginning with '\020' (DLE). CTCPs consist of command name (typically
in upper-case) followed by list of space-separated arguments, which may be
empty.

One use of CTCPs supported by the vast majority of IRC clients today is the
ACTION command, typically invoked with /me. For example, if the user 'foo' in
the channel '#bar' were to issue

> /me dances

everyone in the channel would receive the message

> :foo PRIVMSG #bar :001ACTION dances001

Other common uses of CTCP include requesting the name and version of a user's
IRC client, their local time, determining ping times, and initiating file
transfers (DCC).

Characters are escaped as follows:

['\000' (NUL)] '\020 \060' ("0")

['\012' (NL)] '\020 \156' ("n")

['\015' (CR)] '\020 \162' ("r")

['\020' (DLE)] '\020 \020'

All other appearences of the escape character are errors, and are dropped.

See <http://www.irchelp.org/irchelp/rfc/ctcpspec.html> for more details.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build


%install
%ghc_lib_install


%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.1.3.0 revision 0 with cabal2obs.
